cwlVersion: v1.2
class: Workflow
doc: >-
  The workflow starts with selecting EH38E2924876 as the search term. Genomic
  position of provided unique regulatory element identifier was retrieved from
  CFDE Linked Data Hub[1]. A list of variants in the region of the regulatory
  element was retrieved from CFDE Linked Data Hub[1]. Variant/variant set
  associated allele specific epigenomic signatures were retrieved from CFDE
  LDH[5] based on Roadmap and ENTEx data[6], [4]. GTEx eQTL and sQTL evidence
  for the given variant(s) were retrieved from CFDE LDH[5][3]. MyVariant.info,
  dbSNP, gnomAD, and other common identifiers for the given variant(s) were
  retrieved from ClinGen Allele Registry[7]. Gene(s) in the vicinity of the
  given variant(s) were retrieved from MyVariant.info API results[8]. A list of
  genes in the 10kbps region of the given regulatory element was retrieved from
  CFDE Linked Data Hub[1]. 

  1. CFDE Linked Data Hub, https://ldh.genome.network/cfde/ldh/

  3. The GTEx Consortium atlas of genetic regulatory effects across human
  tissues. Science vol. 369 1318–1330 (2020). doi:10.1126/science.aaz1776

  4. Onuchic, V. et al. Allele-specific epigenome maps reveal sequence-dependent
  stochastic switching at regulatory loci. Science vol. 361 (2018).
  doi:10.1126/science.aar3146

  5. Genomic Location Registry, https://reg.genome.network/reg/loc/

  6. Integrative analysis of 111 reference human epigenomes. Nature vol. 518
  317–330 (2015). doi:10.1038/nature14248

  7. Pawliczek, P. et al. ClinGen Allele Registry links information about
  genetic variants. Human Mutation vol. 39 1690–1701 (2018).
  doi:10.1002/humu.23637

  8. Lelong, S. et al. BioThings SDK: a toolkit for building high-performance
  data APIs in biomedical research. Bioinformatics vol. 38 2077–2079 (2022).
  doi:10.1093/bioinformatics/btac017
requirements: {}
inputs:
  step-1-data:
    label: Regulatory Element Input
    doc: Start with a Regulatory Element
    type: File
  step-6-data:
    label: Select One Variant
    doc: Select one Variant
    type: File
outputs:
  step-1-output:
    label: Regulatory Element
    doc: Regulatory Element Term
    type: File
    outputSource: step-1/output
  step-2-output:
    label: Regulatory Element position
    doc: Regulatory Element position
    type: File
    outputSource: step-2/output
  step-3-output:
    label: Variant Set
    doc: Set of Variants
    type: File
    outputSource: step-3/output
  step-4-output:
    label: Allele Specific Evidence For Variant Set
    doc: ""
    type: File
    outputSource: step-4/output
  step-5-output:
    label: xQTL Evidence For Variant Set
    doc: ""
    type: File
    outputSource: step-5/output
  step-6-output:
    label: Variant
    doc: Variant Term
    type: File
    outputSource: step-6/output
  step-7-output:
    label: Allele Registry External Records Table
    doc: ""
    type: File
    outputSource: step-7/output
  step-8-output:
    label: Gene Associations (HG38)
    doc: ""
    type: File
    outputSource: step-8/output
  step-9-output:
    label: Gene Set
    doc: Set of Genes
    type: File
    outputSource: step-9/output
steps:
  step-1:
    run: Input[Regulatory_Element].cwl
    label: Regulatory Element Input
    doc: Start with a Regulatory Element
    in:
      data:
        source: step-1-data
      outputFilename:
        default: step-1-output.json
    out:
      - output
  step-2:
    run: GetRegulatoryElementPosition.cwl
    label: Retrieve regulatory element position
    doc: Find regulatory element postion (GRCh38)
    in:
      inputs.regulatoryElement:
        label: Regulatory Element
        source: step-1/output
      outputFilename:
        default: step-2-output.json
    out:
      - output
  step-3:
    run: GetVariantListForRegulatoryElementInfo.cwl
    label: Identify Variants Within Regulatory Element
    doc: Retrieve registered variants in the region of given regulatory element from
      Allele Registry
    in:
      inputs.regulatoryElement:
        label: Regulatory Element
        source: step-1/output
      outputFilename:
        default: step-3-output.json
    out:
      - output
  step-4:
    run: GetVariantSetAlleleSpecificEvidence.cwl
    label: Identify Associated Allele Specific Epigenomic Signature
    doc: Retrieve variant/variant set associated allele specific epigenomic
      signatures based on Roadmap and ENTEx data.
    in:
      inputs.variantset:
        label: Variant Set
        source: step-3/output
      outputFilename:
        default: step-4-output.json
    out:
      - output
  step-5:
    run: GetVariantSetXQTLEvidence.cwl
    label: Identify eQTLs and sQTLs and retrieve evidence
    doc: Identify eQTL and sQTL information for the given variant(s) based on GTEx
      data.
    in:
      inputs.variantset:
        label: Variant Set
        source: step-3/output
      outputFilename:
        default: step-5-output.json
    out:
      - output
  step-6:
    run: OneSetT[Set[Variant]].cwl
    label: Select One Variant
    doc: Select one Variant
    in:
      data:
        source: step-6-data
      inputs.set:
        label: Variant Set
        source: step-3/output
      outputFilename:
        default: step-6-output.json
    out:
      - output
  step-7:
    run: GetAlleleRegistryExternalRecordsForVariant.cwl
    label: Retrieve alternative identifiers for variant
    doc: Retrieve MyVariant.info, dbSNP, gnomAD, and other common identifiers for
      given variant from ClinGen Allele Registry.
    in:
      inputs.variant:
        label: Variant
        source: step-6/output
      outputFilename:
        default: step-7-output.json
    out:
      - output
  step-8:
    run: GetVariantToGeneAssociation_HG38.cwl
    label: Identify Variant And Gene Association (HG38)
    doc: Get Associated Gene info for a given Variant.
    in:
      inputs.externalRecords:
        label: Allele Registry External Records Table
        source: step-7/output
      outputFilename:
        default: step-8-output.json
    out:
      - output
  step-9:
    run: GetGenesForRegulatoryElementInfo.cwl
    label: Identify Genes In Vicinity
    doc: Identify genes in 10kbps distance of regulatory element.
    in:
      inputs.regulatoryElement:
        label: Regulatory Element
        source: step-1/output
      outputFilename:
        default: step-9-output.json
    out:
      - output
